@@ -16,9 +16,6 @@ AUD_INPUT_PLUGIN
   .init = adplug_init,
   .cleanup = adplug_quit,
   .play = adplug_play,
-  .stop = adplug_stop,
-  .pause = adplug_pause,
-  .mseek = adplug_mseek,
   .probe_for_tuple = adplug_get_tuple,
   .is_our_file_from_vfs = adplug_is_our_fd,
   .extensions = fmts,
