@@ -33,6 +33,8 @@
 #include <sys/time.h>
 #include <samplerate.h>
 
+#include <glib.h>
+
 #include "bio2jack.h"
 
 /* enable/disable TRACING through the JACK_Callback() function */
@@ -74,35 +76,30 @@ static struct timeval timer_now;
 #endif
 
 #if TRACE_ENABLE
-#define TRACE(format,args...) fprintf(OUTFILE, "%s::%s(%d) "format, __FILE__, __FUNCTION__, __LINE__,##args);	\
-         fflush(OUTFILE);
+#define TRACE(format,args...) fprintf(OUTFILE, "%s::%s(%d) "format, __FILE__, __FUNCTION__, __LINE__,##args)
 #else
 #define TRACE(...)
 #endif
 
 #if DEBUG_OUTPUT
-#define DEBUG(format,args...) fprintf(OUTFILE, "%s::%s(%d) "format, __FILE__, __FUNCTION__, __LINE__,##args);	\
-         fflush(OUTFILE);
+#define DEBUG(format,args...) fprintf(OUTFILE, "%s::%s(%d) "format, __FILE__, __FUNCTION__, __LINE__,##args)
 #else
 #define DEBUG(...)
 #endif
 
 #if TRACE_CALLBACK
-#define CALLBACK_TRACE(format,args...) fprintf(OUTFILE, "%s::%s(%d) "format, __FILE__, __FUNCTION__, __LINE__,##args);	\
-         fflush(OUTFILE);
+#define CALLBACK_TRACE(format,args...) fprintf(OUTFILE, "%s::%s(%d) "format, __FILE__, __FUNCTION__, __LINE__,##args)
 #else
 #define CALLBACK_TRACE(...)
 #endif
 
 #if ENABLE_WARNINGS
-#define WARN(format,args...) fprintf(OUTFILE, "WARN: %s::%s(%d) "format, __FILE__,__FUNCTION__,__LINE__,##args);	\
-         fflush(OUTFILE);
+#define WARN(format,args...) fprintf(OUTFILE, "WARN: %s::%s(%d) "format, __FILE__,__FUNCTION__,__LINE__,##args)
 #else
 #define WARN(...)
 #endif
 
-#define ERR(format,args...) fprintf(OUTFILE, "ERR: %s::%s(%d) "format, __FILE__,__FUNCTION__,__LINE__,##args);	\
-         fflush(OUTFILE);
+#define ERR(format,args...) fprintf(OUTFILE, "ERR: %s::%s(%d) "format, __FILE__,__FUNCTION__,__LINE__,##args)
 
 #define min(a,b)   (((a) < (b)) ? (a) : (b))
 #define max(a,b)   (((a) < (b)) ? (b) : (a))
@@ -282,8 +279,7 @@ getDriver(int deviceID)
 #endif
   jack_driver_t *drv = &outDev[deviceID];
 
-  if(pthread_mutex_lock(&drv->mutex) != 0)
-    ERR("lock returned an error\n");
+  pthread_mutex_lock(&drv->mutex);
 
   /* should we try to restart the jack server? */
   if(drv->jackd_died && drv->client == 0)
@@ -349,8 +345,7 @@ releaseDriver(jack_driver_t * drv)
      TRACE("deviceID == %d\n", drv->deviceID);
      #endif
    */
-  if(pthread_mutex_unlock(&drv->mutex) != 0)
-    ERR("lock returned an error\n");
+  pthread_mutex_unlock(&drv->mutex);
 }
 
 
@@ -532,8 +527,7 @@ JACK_callback(nframes_t nframes, void *arg)
 {
   jack_driver_t *drv = (jack_driver_t *) arg;
 
-  unsigned int i;
-  int src_error = 0;
+  int i, src_error = 0;
 
   TIMER("start\n");
   gettimeofday(&drv->previousTime, 0);  /* record the current time */
@@ -733,7 +727,7 @@ JACK_callback(nframes_t nframes, void *arg)
 
       if(!ensure_buffer_size(&drv->callback_buffer1, &drv->callback_buffer1_size, jack_bytes))
       {
-        ERR("allocated %lu bytes, need %lu bytes\n",
+        ERR("allocated %lu bytes, need %ld bytes\n",
             drv->callback_buffer1_size, jack_bytes);
         return -1;
       }
@@ -978,8 +972,7 @@ JACK_OpenDevice(jack_driver_t * drv)
 {
   const char **ports;
   char *our_client_name = 0;
-  unsigned int i;
-  int failed = 0;
+  int i, failed = 0;
 
   TRACE("creating jack client and setting up callbacks\n");
 
@@ -1002,11 +995,8 @@ JACK_OpenDevice(jack_driver_t * drv)
 
 
   /* build the client name */
-  our_client_name = (char *) malloc(snprintf
-                                    (our_client_name, 0, "%s_%d_%d%02d", client_name, getpid(),
-                                     drv->deviceID, drv->clientCtr + 1) + 1);
-  sprintf(our_client_name, "%s_%d_%d%02d", client_name, getpid(),
-          drv->deviceID, drv->clientCtr++);
+  our_client_name = g_strdup_printf("%s_%d_%d%02d", client_name, getpid(),
+                                    drv->deviceID, drv->clientCtr++);
 
   /* try to become a client of the JACK server */
   TRACE("client name '%s'\n", our_client_name);
@@ -1017,12 +1007,12 @@ JACK_OpenDevice(jack_driver_t * drv)
     if((drv->client = jack_client_open(our_client_name, JackNullOption | JackNoStartServer, NULL)) == 0)
     {
       ERR("jack server not running?\n");
-      free(our_client_name);
+      g_free(our_client_name);
       return ERR_OPENING_JACK;
     }
   }
 
-  free(our_client_name);
+  g_free(our_client_name);
 
   TRACE("setting up jack callbacks\n");
 
@@ -1186,7 +1176,7 @@ JACK_OpenDevice(jack_driver_t * drv)
           }
       }
 
-      free(ports);              /* free the returned array of ports */
+      g_free(ports);              /* free the returned array of ports */
     }
     else
     {
@@ -1213,7 +1203,7 @@ JACK_OpenDevice(jack_driver_t * drv)
           ERR("cannot connect to output port %d('%s')\n", 0, ports[0]);
           failed = 1;
         }
-        free(ports);            /* free the returned array of ports */
+        g_free(ports);            /* free the returned array of ports */
       }
     }
   }                             /* if( drv->num_output_channels > 0 ) */
@@ -1303,7 +1293,7 @@ JACK_OpenDevice(jack_driver_t * drv)
         }
       }
 
-      free(ports);              /* free the returned array of ports */
+      g_free(ports);              /* free the returned array of ports */
     }
     else
     {
@@ -1330,7 +1320,7 @@ JACK_OpenDevice(jack_driver_t * drv)
           ERR("cannot connect to input port %d('%s')\n", 0, ports[0]);
           failed = 1;
         }
-        free(ports);            /* free the returned array of ports */
+        g_free(ports);            /* free the returned array of ports */
       }
     }
   }                             /* if( drv->num_input_channels > 0 ) */
@@ -1396,8 +1386,8 @@ JACK_CloseDevice(jack_driver_t * drv)
     if(drv->jack_port_name_count > 1)
     {
       for(i = 0; i < drv->jack_port_name_count; i++)
-        free(drv->jack_port_name[i]);
-      free(drv->jack_port_name);
+        g_free(drv->jack_port_name[i]);
+      g_free(drv->jack_port_name);
     }
     JACK_CleanupDriver(drv);
 
@@ -1539,6 +1529,7 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
   if(!drv)
   {
     ERR("no more devices available\n");
+    pthread_mutex_unlock(&device_mutex);
     return ERR_OPENING_JACK;
   }
 
@@ -1550,7 +1541,7 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
 
   if(output_channels > MAX_OUTPUT_PORTS)
   {
-    ERR("output_channels == %d, MAX_OUTPUT_PORTS == %d\n", output_channels,
+    ERR("output_channels == %u, MAX_OUTPUT_PORTS == %u\n", output_channels,
         MAX_OUTPUT_PORTS);
     releaseDriver(drv);
     pthread_mutex_unlock(&device_mutex);
@@ -1559,7 +1550,7 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
 
   if(input_channels > MAX_INPUT_PORTS)
   {
-    ERR("input_channels == %d, MAX_INPUT_PORTS == %d\n", input_channels,
+    ERR("input_channels == %u, MAX_INPUT_PORTS == %u\n", input_channels,
         MAX_INPUT_PORTS);
     releaseDriver(drv);
     pthread_mutex_unlock(&device_mutex);
@@ -1576,7 +1567,7 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
      && ((jack_port_name_count < output_channels)
          || (jack_port_name_count < input_channels)))
   {
-    ERR("specified individual port names but not enough, gave %d names, need %d\n",
+    ERR("specified individual port names but not enough, gave %u names, need %u\n",
        jack_port_name_count, output_channels);
     releaseDriver(drv);
     pthread_mutex_unlock(&device_mutex);
@@ -1588,11 +1579,10 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
 
     if(drv->jack_port_name_count != 0)
     {
-      drv->jack_port_name =
-        (char **) malloc(sizeof(char *) * drv->jack_port_name_count);
+      drv->jack_port_name = g_new(char *, drv->jack_port_name_count);
       for(i = 0; i < drv->jack_port_name_count; i++)
       {
-        drv->jack_port_name[i] = strdup(jack_port_name[i]);
+        drv->jack_port_name[i] = g_strdup(jack_port_name[i]);
         TRACE("jack_port_name[%d] == '%s'\n", i, jack_port_name[i]);
       }
     } else
@@ -1727,15 +1717,15 @@ JACK_Close(int deviceID)
 
   /* free buffer memory */
   drv->callback_buffer1_size = 0;
-  if(drv->callback_buffer1) free(drv->callback_buffer1);
+  if(drv->callback_buffer1) g_free(drv->callback_buffer1);
   drv->callback_buffer1 = 0;
 
   drv->callback_buffer2_size = 0;
-  if(drv->callback_buffer2) free(drv->callback_buffer2);
+  if(drv->callback_buffer2) g_free(drv->callback_buffer2);
   drv->callback_buffer2 = 0;
 
   drv->rw_buffer1_size = 0;
-  if(drv->rw_buffer1) free(drv->rw_buffer1);
+  if(drv->rw_buffer1) g_free(drv->rw_buffer1);
   drv->rw_buffer1 = 0;
 
   if(drv->pPlayPtr) jack_ringbuffer_free(drv->pPlayPtr);
@@ -2022,7 +2012,7 @@ JACK_GetVolumeForChannel(int deviceID, unsigned int channel,
   /* ensure that we have the channel we are getting volume for */
   if(channel > (drv->num_output_channels - 1))
   {
-    ERR("asking for channel index %d but we only have %ld channels\n", channel, drv->num_output_channels);
+    ERR("asking for channel index %u but we only have %lu channels\n", channel, drv->num_output_channels);
     releaseDriver(drv);
     return;
   }
@@ -2445,13 +2435,14 @@ JACK_GetMaxOutputBufferedBytes(int deviceID)
   jack_driver_t *drv = getDriver(deviceID);
   long return_val;
 
-  if(drv->pPlayPtr == 0 || drv->bytes_per_jack_output_frame == 0) return_val = 0;
-
   /* adjust from jack bytes to client bytes */
-  return_val =
-    (jack_ringbuffer_read_space(drv->pPlayPtr) +
-     jack_ringbuffer_write_space(drv->pPlayPtr)) /
-    drv->bytes_per_jack_output_frame * drv->bytes_per_output_frame;
+  if(drv->pPlayPtr == 0 || drv->bytes_per_jack_output_frame == 0)
+    return_val = 0;
+  else
+    return_val =
+      (jack_ringbuffer_read_space(drv->pPlayPtr) +
+       jack_ringbuffer_write_space(drv->pPlayPtr)) /
+      drv->bytes_per_jack_output_frame * drv->bytes_per_output_frame;
 
   releaseDriver(drv);
 
@@ -2467,13 +2458,14 @@ JACK_GetMaxInputBufferedBytes(int deviceID)
   jack_driver_t *drv = getDriver(deviceID);
   long return_val;
 
-  if(drv->pRecPtr == 0 || drv->bytes_per_jack_input_frame == 0) return_val = 0;
-
   /* adjust from jack bytes to client bytes */
-  return_val =
-    (jack_ringbuffer_read_space(drv->pRecPtr) +
-     jack_ringbuffer_write_space(drv->pRecPtr)) /
-    drv->bytes_per_jack_input_frame * drv->bytes_per_input_frame;
+  if(drv->pRecPtr == 0 || drv->bytes_per_jack_input_frame == 0)
+    return_val = 0;
+  else
+    return_val =
+      (jack_ringbuffer_read_space(drv->pRecPtr) +
+       jack_ringbuffer_write_space(drv->pRecPtr)) /
+      drv->bytes_per_jack_input_frame * drv->bytes_per_input_frame;
 
   releaseDriver(drv);
 
@@ -2647,19 +2639,9 @@ JACK_SetClientName(char *name)
 {
   if(name)
   {
-    if(client_name) free(client_name);
+    if(client_name) g_free(client_name);
 
-    /* jack_client_name_size() is the max length of a client name, including
-       the terminating null. */
-    int size = strlen(name) + 1;        /* take into account the terminating null */
-    if(size > jack_client_name_size())
-      size = jack_client_name_size();
-
-    client_name = malloc(size);
-    if(client_name)
-      snprintf(client_name, size, "%s", name);
-    else
-      ERR("unable to allocate %d bytes for client_name\n", size);
+    client_name = g_strdup(name);
   }
 }
 
