@@ -23,21 +23,28 @@
 
 #include "xs_support.h"
 
-#include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include <glib.h>
+
 uint16_t xs_fread_be16(VFSFile *f)
 {
     uint16_t val;
-    return vfs_fget_be16(&val, f) ? val : 0;
+    if (vfs_fread (& val, 1, sizeof val, f) != sizeof val)
+        return 0;
+
+    return GUINT16_FROM_BE (val);
 }
 
 
 uint32_t xs_fread_be32(VFSFile *f)
 {
     uint32_t val;
-    return vfs_fget_be32(&val, f) ? val : 0;
+    if (vfs_fread (& val, 1, sizeof val, f) != sizeof val)
+        return 0;
+
+    return GUINT32_FROM_BE (val);
 }
 
 
@@ -89,7 +96,7 @@ int xs_pstrcat(char **result, const char *str)
 
 void xs_findnext(const char *str, size_t *pos)
 {
-    while (str[*pos] && isspace(str[*pos]))
+    while (str[*pos] && g_ascii_isspace(str[*pos]))
         (*pos)++;
 }
 
@@ -103,7 +110,7 @@ void xs_findeol(const char *str, size_t *pos)
 
 void xs_findnum(const char *str, size_t *pos)
 {
-    while (str[*pos] && isdigit(str[*pos]))
+    while (str[*pos] && g_ascii_isdigit(str[*pos]))
         (*pos)++;
 }
 
